<?php

/**
 * @author 1178 Team
 * @package ExpMetaBoxes
 * @license GNU General Public License v2 or later
**/


defined("EXP_EXEC") or die("Silent is golden");

/**
 * ExpPluginOptions
**/
class ExpPluginOptions{

	/**
	 * ExpPluginOptions:exp_api_settings_setting()
	**/
	private $exp_api_settings_setting = array();



	/**
	 * ExpPluginOptions:__construct()
	**/
	function __construct()
	{
		if(is_admin()){
			// api-settings
			$this->exp_api_settings_setting = get_option("exp_api_settings_setting");
			add_action("admin_menu",array($this,"expAddApiSettingsPageOption"));
			add_action("admin_init",array($this,"expAddApiSettingsPageInit"));
			add_action("admin_footer",array($this,"expApiSettingsAdminFooter"));
			add_action("admin_enqueue_scripts",array($this,"expApiSettingsAdminEnqueueScripts"));
			
		}
	}




	// TODO: API-SETTINGS--------------------------------------------------------------------------


	/**
	 * ExpPluginOptions:expAddApiSettingsPageOption()
	 * @ref: https://developer.wordpress.org/reference/functions/add_options_page/
	**/
	function expAddApiSettingsPageOption()
	{
		add_options_page(
			__("EverXP - API Settings","everxp"), //$page_title
			__("EverXP - API Settings","everxp"), //$menu_title
			"manage_options", //$capability
			"exp_api_settings",//$menu_slug
			array($this,"expApiSettingsPageContent")//$function
		);
	}


	/**
	 * ExpPluginOptions:expApiSettingsPageContent()
	**/
	function expApiSettingsPageContent()
	{
		$this->exp_api_settings_setting = get_option("exp_api_settings_setting");
		?>
		<div class="wrap">
			<h1><?php _e("EverXP - API Settings","everxp") ?></h1>
			<div class="exp-box">
				<div class="inside">
					<form method="post" action="options.php">
						<?php settings_fields("exp_api_settings_group"); ?>
						<?php do_settings_sections("exp-api-settings"); ?>
						<?php submit_button(); ?>
					</form>
				</div>
			</div>
		</div>
		<?php
	}


	/**
	 * ExpPluginOptions:expAddApiSettingsPageInit()
	**/
	function expAddApiSettingsPageInit()
	{
		
		
		register_setting(
			"exp_api_settings_group",// group
			"exp_api_settings_setting", //setting name
			array($this,"expAddApiSettingsSanitize") //sanitize_callback
		);
		
		
		add_settings_section(
			"exp_api_settings_section", //id
			__("General Settings","everxp"), //title
			array($this,"expAddApiSettingsInfo"), //callback
			"exp-api-settings" //page
		);
		
		// email
		add_settings_field(
			"exp_email", //id
			__("Email","everxp"), //title
			array($this,"expEmailCallback"), //callback
			"exp-api-settings", //page
			"exp_api_settings_section" //section
		);
		
		// api-key
		add_settings_field(
			"exp_api_key", //id
			__("API Key","everxp"), //title
			array($this,"expApiKeyCallback"), //callback
			"exp-api-settings", //page
			"exp_api_settings_section" //section
		);
	}


	/**
	 * ExpPluginOptions:expAddApiSettingsSanitize()
	**/
	function expAddApiSettingsSanitize($input)
	{
		$new_input = array();
		
		
		// email
		if(isset($input["exp_email"]))
			$new_input["exp_email"] = sanitize_text_field($input["exp_email"]);
		
		
		
		// api-key
		if(isset($input["exp_api_key"]))
			$new_input["exp_api_key"] = sanitize_text_field($input["exp_api_key"]);
		
		return $new_input;
	}


	/**
	 * ExpPluginOptions:expAddApiSettingsInfo()
	**/
	function expAddApiSettingsInfo()
	{
		_e("Enter your settings below:","everxp");
	}
	
	
	/**
	 * ExpPluginOptions:expEmailCallback()
	**/
	function expEmailCallback(){
	
		if(isset($this->exp_api_settings_setting["exp_email"])){
			$value = esc_attr($this->exp_api_settings_setting["exp_email"]);
		}else{
			$value = "";
		}
		?>
		<input class="regular-text" id="exp-email" type="email" name="exp_api_settings_setting[exp_email]" placeholder="name@email.com" value="<?php echo $value; ?>" />
		<p class="description"><?php _e("","everxp") ?></p>
		<?php
	}
	
	
	/**
	 * ExpPluginOptions:expApiKeyCallback()
	**/
	function expApiKeyCallback(){
	
		if(isset($this->exp_api_settings_setting["exp_api_key"])){
			$value = esc_attr($this->exp_api_settings_setting["exp_api_key"]);
		}else{
			$value = "";
		}
		?>
		<input class="regular-text" id="exp-api-key" type="text" name="exp_api_settings_setting[exp_api_key]" placeholder="kjgh5jkjfdg==" value="<?php echo $value; ?>" />
		<p class="description"><?php _e("","everxp") ?></p>
		<?php
	}
	
	
	
	
	/**
	 * ExpPluginOptions:expApiSettingsAdminFooter($hook)
	**/
	function expApiSettingsAdminFooter()
	{
		$screen = get_current_screen();
		if($screen->id == "settings_page_exp_api_settings")
		{
			//email
			
			//api-key
			
		}
	}
	
	
	/**
	 * ExpPluginOptions:expApiSettingsAdminEnqueueScripts($hook)
	**/
	function expApiSettingsAdminEnqueueScripts($hook)
	{
		$screen = get_current_screen();
		if($screen->id == "settings_page_exp_api_settings")
		{
			//email
			
			//api-key
			
		}
	}
	
	
}
